@@ -16,8 +16,8 @@
 
 """Expose package-wide elements."""
 
-__version__ = "5.11.5"
-""" Examples of valid version strings according :pep:`440#version-scheme`:
+__version__ = "5.12.0"
+"""Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
 
@@ -29,4 +29,4 @@ __version__ = "5.11.5"
     __version__ = "1.2.3.post1"  # Post Release 1
 """
 
-from click_extra.logging import logger
+from click_extra.logging import logger  # noqa: F401, E402
