@@ -23,17 +23,20 @@ from contextlib import nullcontext
 from dataclasses import asdict, dataclass
 from enum import Enum
 from pathlib import Path
-from shutil import which
 from textwrap import dedent, indent, shorten
-from typing import ContextManager, Iterable, Iterator, cast
+from typing import ContextManager, Iterable, Iterator, Generator
 from unittest.mock import patch
 
 if sys.version_info >= (3, 8):
     from functools import cached_property
+    from shutil import _WIN_DEFAULT_PATHEXT
 else:
     from boltons.cacheutils import cachedproperty as cached_property
 
-from boltons.iterutils import flatten
+    # XXX Copy of https://github.com/python/cpython/blob/edbde8f/Lib/shutil.py#L49
+    _WIN_DEFAULT_PATHEXT = ".COM;.EXE;.BAT;.CMD;.VBS;.JS;.WS;.MSC"
+
+from boltons.iterutils import flatten, unique
 from boltons.strutils import strip_ansi
 from click_extra.colorize import default_theme as theme
 from click_extra.platforms import Group, Platform, current_os, is_linux
@@ -64,14 +67,14 @@ Operations = Enum(
         "cleanup",
     ),
 )
-"""Recognized operation IDs that are implemented by package manager with their specific CLI invocation.
+"""Recognized operation IDs that are implemented by package manager with their specific
+CLI invocation.
 
 Each operation has its own CLI subcommand.
 """
 
 
 class CLIError(Exception):
-
     """An error occurred when running package manager CLI."""
 
     def __init__(self, code: int, output: str, error: str):
@@ -109,7 +112,7 @@ class Package:
     """Lightweight representation of a package and its metadata."""
 
     id: str
-    """ID is required and is the primary key used by the manager. """
+    """ID is required and is the primary key used by the manager."""
 
     name: str | None = None
 
@@ -117,9 +120,15 @@ class Package:
 
     installed_version: TokenizedString | str | None = None
     latest_version: TokenizedString | str | None = None
-    """ ``installed_version`` and ``latest_version`` are allowed to temporarily be a string
-    between ``__init__`` and ``__post_init__``. Once they reach the later, they're parsed and
-    normalized into ``TokenizedString``.
+    """Installed and latest versions are optional: they're not always provided by the
+    package manager.
+
+    ``installed_version`` and ``latest_version`` are allowed to temporarily be strings
+    between ``__init__`` and ``__post_init__``. Once they reach the later, they're
+    parsed and normalized into either ``TokenizedString`` or `None`. They can't be
+    strings beyong that point, i.e. after the Package instance has been fully
+    instantiated. We don't know how to declare this transient state with type hints,
+    so we're just going to allow string type.
     """
 
     def __post_init__(self) -> None:
@@ -166,53 +175,57 @@ class MetaPackageManager(type):
             cls.platforms = frozenset(platforms)
 
 
-def highlight_cli_name(
-    path: Path | None, match_names: tuple[str, ...] | None = None
-) -> str | None:
+def highlight_cli_name(path: Path | None, match_names: Iterable[str]) -> str | None:
     """Highlight the binary name in the provided ``path``
 
-    If ``match_names`` is provided, only highlight if the binary name is in the list, regardless of the the case.
+    If ``match_names`` is provided, only highlight the start of the binary name that is
+    in the list.
 
-    Takes care of extensions (e.g. ``.exe`` on Windows) and returns a string.
+    Matchin is insensitive to case on Windows and case-sensitive on other platforms,
+    thanks to ``os.path.normcase``.
     """
     if path is None:
         return None
-    suffixes = path.suffixes
-    # Strip all suffixes from the full name of the binary.
-    bin_name = path.name
-    for suffix in suffixes[::-1]:
-        bin_name = bin_name.rstrip(suffix)
-    if not match_names or bin_name.lower() in (name.lower() for name in match_names):
-        bin_name = theme.invoked_command(bin_name)
-    return f"{path.parent}{os.path.sep}{bin_name}{''.join(suffixes)}"
+
+    highlighted_name = path.name
+    for ref_name in match_names:
+        if os.path.normcase(ref_name).startswith(os.path.normcase(path.name)):
+            highlighted_name = (
+                theme.invoked_command(path.name[: len(ref_name)])
+                + path.name[len(ref_name) :]
+            )
+            break
+
+    return f"{path.parent}{os.path.sep}{highlighted_name}"
 
 
 class PackageManager(metaclass=MetaPackageManager):
-
     """Base class from which all package manager definitions inherits."""
 
     deprecated: bool = False
-    """A manager marked as deprecated will be hidden from all package selection by default.
+    """A manager marked as deprecated will be hidden from all package selection by
+    default.
 
     You can still use it but need to explicitly call for it on the command line.
 
-    Implementation of a deprecated manager will be kept within mpm source code, but some of its
-    features or total implementation are allowed to be scraped in the face of
+    Implementation of a deprecated manager will be kept within mpm source code, but some
+    of its features or total implementation are allowed to be scraped in the face of
     maintenance pain and adversity.
 
-    Integration tests and unittests for deprecated managers can be removed. We do not care if
-    a deprecated manager is not 100% reliable. A flakky deprecated manager should not block a
-    release due to flakky tests.
+    Integration tests and unittests for deprecated managers can be removed. We do not
+    care if a deprecated manager is not 100% reliable. A flakky deprecated manager
+    should not block a release due to flakky tests.
     """
 
     deprecation_url: str | None = None
-    """Announcement from the official project or evidence of abandonment of maintainance."""
+    """Announcement from the official project or evidence of abandonment of
+    maintainance."""
 
     id: str
     """Package manager's ID.
 
-    Derived by defaults from the lower-cased class name in which underscores ``_`` are replaced
-    by dashes ``-``.
+    Derived by defaults from the lower-cased class name in which underscores ``_`` are
+    replaced by dashes ``-``.
 
     This ID must be unique among all package manager definitions and lower-case, as
     they're used as feature flags for the :program:`mpm` CLI.
@@ -232,14 +245,15 @@ class PackageManager(metaclass=MetaPackageManager):
     ] = frozenset()
     """List of platforms supported by the manager.
 
-    Allows for a mishmash of platforms and groups. Will be normalized into a frozen set of
-    ``Platform`` instances at instanciation.
+    Allows for a mishmash of platforms and groups. Will be normalized into a frozen set
+    of ``Platform`` instances at instanciation.
     """
 
     requirement: str | None = None
     """Minimal required version.
 
-    Should be a string parseable by :py:class:`meta_package_manager.version.parse_version`.
+    Should be a string parseable by
+    :py:class:`meta_package_manager.version.parse_version`.
 
     Defaults to ``None``, which deactivate version check entirely.
     """
@@ -247,9 +261,8 @@ class PackageManager(metaclass=MetaPackageManager):
     cli_names: tuple[str, ...]
     """List of CLI names the package manager is known as.
 
-    The supported CLI names are ordered by priority. This is used for example to
-    help out the search of the right binary in the case of the python3/python2
-    transition.
+    The supported CLI names are ordered by priority. This is used for example to help
+    out the search of the right binary in the case of the python3/python2 transition.
 
     Is derived by default from the manager's ID.
     """
@@ -262,26 +275,27 @@ class PackageManager(metaclass=MetaPackageManager):
     """
 
     cli_search_path: tuple[str, ...] = ()
-    """ List of additional path to help :program:`mpm` hunt down the package manager CLI.
+    """List of additional path to help :program:`mpm` hunt down the package manager CLI.
 
     Must be a list of strings whose order dictates the search sequence.
 
-    Most of the time unnecessary: :py:func:`meta_package_manager.base.PackageManager.cli_path`
-    works well on all platforms.
+    Most of the time unnecessary:
+    :py:func:`meta_package_manager.base.PackageManager.cli_path` works well on all
+    platforms.
     """
 
     extra_env: EnvVars | None = None
     """Additional environment variables to add to the current context.
 
-    Automatically applied on each :py:func:`meta_package_manager.base.PackageManager.run_cli`
-    calls.
+    Automatically applied on each
+    :py:func:`meta_package_manager.base.PackageManager.run_cli` calls.
     """
 
     pre_cmds: tuple[str, ...] = ()
     """Global list of pre-commands to add before before invoked CLI.
 
-    Automatically added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
-    call.
+    Automatically added to each
+    :py:func:`meta_package_manager.base.PackageManager.run_cli` call.
 
     Used to prepend `sudo <https://www.sudo.ws>`_ or other system utilities.
     """
@@ -290,8 +304,8 @@ class PackageManager(metaclass=MetaPackageManager):
     post_args: tuple[str, ...] = ()
     """Global list of options used before and after the invoked package manager CLI.
 
-    Automatically added to each :py:func:`meta_package_manager.base.PackageManager.run_cli`
-    call.
+    Automatically added to each
+    :py:func:`meta_package_manager.base.PackageManager.run_cli` call.
 
     Essentially used to force silencing, low verbosity or no-color output.
     """
@@ -300,9 +314,9 @@ class PackageManager(metaclass=MetaPackageManager):
     """List of options to get the version from the package manager CLI."""
 
     version_regex: str = r"(?P<version>\S+)"
-    """ Regular expression used to extract the version number from the result of the CLI
-    run with the options above. It doesn't matter if the regex returns unsanitized
-    and crappy string. The :py:func:`meta_package_manager.base.PackageManager.version`
+    """Regular expression used to extract the version number from the result of the CLI
+    run with the options above. It doesn't matter if the regex returns unsanitized and
+    crappy string. The :py:func:`meta_package_manager.base.PackageManager.version`
     method will clean and normalized it.
 
     By default match the first part that is space-separated.
@@ -312,8 +326,8 @@ class PackageManager(metaclass=MetaPackageManager):
     """Tell the manager to either raise or continue on errors."""
 
     ignore_auto_updates: bool = True
-    """Some managers can report or ignore packages which have their own auto-update mechanism.
-    """
+    """Some managers can report or ignore packages which have their own auto-update
+    mechanism."""
 
     dry_run: bool = False
     """Do not actually perform any action, just simulate CLI calls."""
@@ -341,19 +355,22 @@ class PackageManager(metaclass=MetaPackageManager):
         if op == Operations.upgrade:
             method_deps = ({"installed", "upgrade_one_cli"},)
 
-        # For `upgrade_all`: we depends on eother `upgrade_all_cli()`, or we can simulate the latter with a combination of
-        # `outdated()` and `upgrade_one_cli()`.
+        # For `upgrade_all`: we depends on eother `upgrade_all_cli()`, or we can
+        # simulate the latter with a combination of `outdated()` and
+        # `upgrade_one_cli()`.
         elif op == Operations.upgrade_all:
             method_deps = ({"upgrade_all_cli"}, {"outdated", "upgrade_one_cli"})
 
-        # If none of the classes in the inheritance hierarchy up to the base one implements the operation, then we can be certain
-        # the manager doesn't implement the operation at all.
+        # If none of the classes in the inheritance hierarchy up to the base one
+        # implements the operation, then we can be certain the manager doesn't implement
+        # the operation at all.
         for klass in cls.mro():
             if klass is PackageManager:
                 return False
-            # Presence of the operation function is not enough to rules out proper implementation, as it can
-            # be a method that raises NotImplemented error anyway. See for instance the upgrade_all_cli in pip.py:
-            # https://github.com/kdeldycke/meta-package-manager/blob/4acc003bd268a59f5a79cf317be6d25a90878f6d/meta_package_manager/managers/pip.py#L271-L279
+            # Presence of the operation function is not enough to rules out proper
+            # implementation, as it can be a method that raises NotImplemented error
+            # anyway. See for instance the upgrade_all_cli in pip.py:
+            # https://github.com/kdeldycke/meta-package-manager/blob/4acc003/meta_package_manager/managers/pip.py#L271-L279
             for method_ids in method_deps:
                 all_deps_found = method_ids.issubset(klass.__dict__)
                 if all_deps_found:
@@ -361,61 +378,127 @@ class PackageManager(metaclass=MetaPackageManager):
 
         raise NotImplementedError(f"Can't guess {cls} implementation of {op}.")
 
-    def search_cli(self, cli_name: str) -> Path | None:
-        """Search for a CLI on the system.
+    def search_all_cli(
+        self, cli_names: Iterable[str], env=None
+    ) -> Generator[Path, None, None]:
+        """Search for all binary files matching the CLI names, in all environment path.
 
-        Look for the provided ``cli_name`` in this order:
-          * first in paths provided by
-            :py:attr:`cli_search_path <meta_package_manager.base.PackageManager.cli_search_path>`,
-          * then in all the default places specified by the environment variable (i.e. ``os.getenv("PATH")``).
+        This is like our own implementation of ``shutil.which()``, with the difference
+        that it is capable of returning all the possible paths of the provided file
+        names, in all environment path, not just the first one that match. And on
+        Windows, prevents matching of CLI in the current directory, which takes
+        precedence on other paths.
 
-        Only checks if the file exists. Not its executability.
+        Returns all files matching any ``cli_names``, by iterating over all folders in
+        this order:
+          * folders provided by :py:attr:`cli_search_path
+            <meta_package_manager.base.PackageManager.cli_search_path>`,
+          * then in all the default places specified by the environment variable (i.e.
+            ``os.getenv("PATH")``).
 
-        Returns ``None`` if the CLI was not found or is not a file.
+        Only returns files that exists and are not empty.
 
         .. caution::
 
-            Symlinks are not resolved, because some manager like Homebrew on Linux relies on some
-            sort of symlink-based trickery to set environment variables.
+            Symlinks are not resolved, because some manager like `Homebrew on Linux
+            relies on some sort of symlink-based trickery
+            <https://github.com/kdeldycke/meta-package-manager/pull/188>`_ to set
+            environment variables.
         """
-        # Locally extend the environment to add manager-specific search path.
-        env_path = ":".join(flatten((self.cli_search_path, os.getenv("PATH"))))
+        # Check CLI names are not path, but plain filenames.
+        for cli_name in cli_names:
+            assert not os.path.dirname(
+                cli_name
+            ), f"CLI name {cli_name} contains path separator {os.path.sep}."
 
-        cli_path_found = which(cli_name, mode=os.F_OK, path=env_path)
-        if not cli_path_found:
-            logger.debug(f"{theme.invoked_command(cli_name)} CLI not found.")
-            return None
+        # Validates each search path.
+        for cli_search_path in self.cli_search_path:
+            assert os.pathsep not in cli_search_path, (
+                f"Search path {cli_search_path} contains "
+                f"environment path separator {os.pathsep}."
+            )
 
-        # Check if path exist and is a file.
-        cli_path = Path(cli_path_found)
-        if not cli_path.exists():
-            raise FileNotFoundError(cli_path)
-        elif not cli_path.is_file():
-            logger.warning(f"{highlight_cli_name(cli_path)} is not a file.")
-            return None
+        # By default, the filename to search for is the case-sensitive CLI name.
+        search_filenames = list(cli_names)
+        # But on Windows, there is this special ``PATHEXT`` environment variable to
+        # tell you what file suffixes are executable. We have to search for any
+        # variation of the CLI name with any of these suffixes.
+        # Code below is inpired by the original implementation of ``shutil.which()``:
+        # https://github.com/python/cpython/blob/8d46c7e/Lib/shutil.py#L1478-L1491
+        if sys.platform == "win32":
+            pathext_source = os.getenv("PATHEXT") or _WIN_DEFAULT_PATHEXT
+            pathext = unique((ext for ext in pathext_source.split(os.pathsep) if ext))
+            search_filenames = []
+            for cli_name in cli_names:
+                # See if the given file matches any of the expected path extensions.
+                # This will allow us to short circuit when given "python.exe".
+                # If it does match, only test that one, otherwise we have to try
+                # others.
+                if any(cli_name.lower().endswith(ext.lower()) for ext in pathext):
+                    search_filenames.append(cli_name)
+                else:
+                    search_filenames.extend(f"{cli_name}{ext}" for ext in pathext)
+        search_filenames = unique(search_filenames)
 
-        logger.debug(f"CLI found at {highlight_cli_name(cli_path)}")
-        return cli_path
+        def normalize_path(path: Path) -> str:
+            """Resolves symlinks and produces a normalized absolute path string.
+
+            Additonnaly use ``os.path.normcase`` on Windows to exclude duplicates
+            produced by case-insensitive filesystems.
+            """
+            return os.path.normcase(path.resolve())
+
+        # Deduplicate search paths while keeping their order and original value, as the
+        # normalization process happens with the ``key`` lookup.
+        search_path_list: list[Path] = unique(
+            # Manager-specific search path takes precedence over default environment.
+            (Path(p) for p in list(self.cli_search_path) + os.get_exec_path(env=env)),
+            key=normalize_path,
+        )
+
+        logger.debug(
+            "Search for "
+            + ", ".join((theme.invoked_command(cli) for cli in search_filenames))
+            + " in "
+            + ", ".join(str(p) for p in search_path_list)
+        )
+
+        for search_path in search_path_list:
+            if not search_path.is_dir():
+                continue
+
+            for filename in search_filenames:
+                file = search_path / filename
+                if not file.is_file() or not os.path.getsize(file):
+                    continue
+                logger.debug(f"CLI found at {highlight_cli_name(file, cli_names)}")
+                yield file
+
+    def which(self, cli_name: str) -> Path | None:
+        """Emulates the ``which`` command.
+
+        Based on the ``search_all_cli()`` method.
+        """
+        for cli_path_found in self.search_all_cli([cli_name]):
+            return cli_path_found
+        return None
 
     @cached_property
     def cli_path(self) -> Path | None:
         """Fully qualified path to the canonical package manager binary.
 
-        Automatically search the location of the CLI in the system. Try multiple CLI
-        names provided by :py:attr:`cli_names <meta_package_manager.base.PackageManager.cli_names>`,
-        in all system path provided by
-        :py:attr:`cli_search_path <meta_package_manager.base.PackageManager.cli_search_path>`.
+        Try each CLI names provided by :py:attr:`cli_names
+        <meta_package_manager.base.PackageManager.cli_names>`, in each system path
+        provided by :py:attr:`cli_search_path
+        <meta_package_manager.base.PackageManager.cli_search_path>`. In that order.
+        Then returns the first match.
 
-        Executability of the CLI will be separatel assessed later by
-        the :py:func:`meta_package_manager.base.PackageManager.executable` method below.
+        Executability of the CLI will be separately assessed later by the
+        :py:func:`meta_package_manager.base.PackageManager.executable` method below.
         """
-        # Search for multiple CLI names.
         if self.cli_names is not None:
-            for name in self.cli_names:
-                cli_path_found = self.search_cli(name)
-                if cli_path_found:
-                    return cli_path_found
-
+            for cli_path in self.search_all_cli(self.cli_names):
+                return cli_path
         return None
 
     @cached_property
@@ -444,7 +527,8 @@ class PackageManager(metaclass=MetaPackageManager):
                 # application" error.
                 if getattr(ex, "winerror", None) == 193:
                     logger.debug(
-                        f"{theme.invoked_command(str(self.cli_path))} is not a valid Windows application."
+                        f"{theme.invoked_command(str(self.cli_path))} "
+                        "is not a valid Windows application."
                     )
                     # Declare CLI as un-executable.
                     self.executable = False
@@ -478,7 +562,8 @@ class PackageManager(metaclass=MetaPackageManager):
             return False
         if not os.access(self.cli_path, os.X_OK):
             logger.debug(
-                f"{highlight_cli_name(self.cli_path)} is not allowed to be executed."
+                f"{highlight_cli_name(self.cli_path, self.cli_names)} "
+                "is not allowed to be executed."
             )
             return False
         return True
@@ -504,16 +589,20 @@ class PackageManager(metaclass=MetaPackageManager):
 
         Returns ``True`` only if the main CLI:
 
-        1. is :py:attr:`supported on the current platform <meta_package_manager.base.PackageManager.supported>`,
-        2. was :py:attr:`found on the system <meta_package_manager.base.PackageManager.cli_path>`,
-        3. is :py:attr:`executable <meta_package_manager.base.PackageManager.executable>`, and
-        4. :py:attr:`match the version requirement <meta_package_manager.base.PackageManager.fresh>`.
+        1. is :py:attr:`supported on the current platform
+           <meta_package_manager.base.PackageManager.supported>`,
+        2. was :py:attr:`found on the system
+           <meta_package_manager.base.PackageManager.cli_path>`,
+        3. is :py:attr:`executable
+           <meta_package_manager.base.PackageManager.executable>`, and
+        4. :py:attr:`match the version requirement
+           <meta_package_manager.base.PackageManager.fresh>`.
         """
         logger.debug(
             f"{self.id} "
             f"is deprecated: {self.deprecated}; "
             f"is supported: {self.supported}; "
-            f"found at: {highlight_cli_name(self.cli_path)}; "
+            f"found at: {highlight_cli_name(self.cli_path, self.cli_names)}; "
             f"is executable: {self.executable}; "
             f"is fresh: {self.fresh}."
         )
@@ -528,13 +617,17 @@ class PackageManager(metaclass=MetaPackageManager):
 
         Running commands with that method takes care of:
           * adding logs at the appropriate level
-          * removing ANSI escape codes from :py:attr:`subprocess.CompletedProcess.stdout` and :py:attr:`subprocess.CompletedProcess.stderr`
+          * removing ANSI escape codes from
+            :py:attr:`subprocess.CompletedProcess.stdout` and
+            :py:attr:`subprocess.CompletedProcess.stderr`
           * returning ready-to-use normalized strings (dedented and stripped)
-          * letting :option:`mpm --dry-run` and :option:`mpm --stop-on-error` have expected effect on execution
+          * letting :option:`mpm --dry-run` and :option:`mpm --stop-on-error` have
+            expected effect on execution
 
         .. todo::
 
-            Move :option:`mpm --dry-run` option and this method to `click-extra <https://github.com/kdeldycke/click-extra>`_.
+            Move :option:`mpm --dry-run` option and this method to `click-extra
+            <https://github.com/kdeldycke/click-extra>`_.
         """
         # Casting to string helps serialize Path and Version objects.
         clean_args = args_cleanup(*args)
@@ -594,26 +687,33 @@ class PackageManager(metaclass=MetaPackageManager):
 
         Returns a tuple of strings.
 
-        Helps the construction of CLI's repeating patterns and makes the code easier to read. Just pass the
-        specific ``*args`` and the full CLI string will be composed out of the globals,
-        following this schema:
+        Helps the construction of CLI's repeating patterns and makes the code easier to
+        read. Just pass the specific ``*args`` and the full CLI string will be composed
+        out of the globals, following this schema:
 
         .. code-block:: shell-session
 
-            $ [<self.pre_cmds>|sudo] <self.cli_path> <self.pre_args> <*args> <self.post_args>
+            $ [<pre_cmds>|sudo] <cli_path> <pre_args> <*args> <post_args>
 
-        * :py:attr:`self.pre_cmds <meta_package_manager.base.PackageManager.pre_cmds>` is added before the CLI path.
+        * :py:attr:`self.pre_cmds <meta_package_manager.base.PackageManager.pre_cmds>`
+          is added before the CLI path.
 
-        * :py:attr:`self.cli_path <meta_package_manager.base.PackageManager.cli_path>` is used as the main binary to execute.
+        * :py:attr:`self.cli_path <meta_package_manager.base.PackageManager.cli_path>`
+          is used as the main binary to execute.
 
-        * :py:attr:`self.pre_args <meta_package_manager.base.PackageManager.pre_args>` and :py:attr:`self.post_args <meta_package_manager.base.PackageManager.post_args>`  globals are added before and after
-          the provided ``*args``.
+        * :py:attr:`self.pre_args <meta_package_manager.base.PackageManager.pre_args>`
+          and :py:attr:`self.post_args
+          <meta_package_manager.base.PackageManager.post_args>`  globals are added
+          before and after the provided ``*args``.
 
         Each additional set of elements can be disabled with their respective flag:
 
-        * ``auto_pre_cmds=False``  to skip the automatic addition of :py:attr:`self.pre_cmds <meta_package_manager.base.PackageManager.pre_cmds>`
-        * ``auto_pre_args=False``  to skip the automatic addition of :py:attr:`self.pre_args <meta_package_manager.base.PackageManager.pre_args>`
-        * ``auto_post_args=False`` to skip the automatic addition of :py:attr:`self.post_args <meta_package_manager.base.PackageManager.post_args>`
+        * ``auto_pre_cmds=False``  to skip the automatic addition of
+          :py:attr:`self.pre_cmds <meta_package_manager.base.PackageManager.pre_cmds>`
+        * ``auto_pre_args=False``  to skip the automatic addition of
+          :py:attr:`self.pre_args <meta_package_manager.base.PackageManager.pre_args>`
+        * ``auto_post_args=False`` to skip the automatic addition of
+          :py:attr:`self.post_args <meta_package_manager.base.PackageManager.post_args>`
 
         Each global set of elements can be locally overridden with:
 
@@ -622,8 +722,10 @@ class PackageManager(metaclass=MetaPackageManager):
         * ``override_pre_args=tuple()``
         * ``override_post_args=tuple()``
 
-        On linux, the command can be run with `sudo <https://www.sudo.ws>`_ if the parameter of the same name is set to ``True``.
-        In which case the ``override_pre_cmds`` parameter is not allowed to be set and the ``auto_pre_cmds`` parameter is forced to ``False``.
+        On linux, the command can be run with `sudo <https://www.sudo.ws>`_ if the
+        parameter of the same name is set to ``True``. In which case the
+        ``override_pre_cmds`` parameter is not allowed to be set and the
+        ``auto_pre_cmds`` parameter is forced to ``False``.
         """
         params: list[Arg | NestedArgs] = []
 
@@ -679,16 +781,20 @@ class PackageManager(metaclass=MetaPackageManager):
         """Build and run the package manager CLI by combining the custom ``*args`` with
         the package manager's global parameters.
 
-        After the CLI is built with the :py:meth:`meta_package_manager.base.PackageManager.build_cli` method, it is executed with
-        the :py:meth:`meta_package_manager.base.PackageManager.run` method, augmented with
-        environment variables from :py:attr:`self.extra_env <meta_package_manager.base.PackageManager.extra_env>`.
+        After the CLI is built with the
+        :py:meth:`meta_package_manager.base.PackageManager.build_cli` method, it is
+        executed with the :py:meth:`meta_package_manager.base.PackageManager.run`
+        method, augmented with environment variables from :py:attr:`self.extra_env
+        <meta_package_manager.base.PackageManager.extra_env>`.
 
-        All parameters are the same as :py:meth:`meta_package_manager.base.PackageManager.build_cli`, plus:
+        All parameters are the same as
+        :py:meth:`meta_package_manager.base.PackageManager.build_cli`, plus:
 
-        * ``auto_extra_env=False`` to skip the automatic addition of :py:attr:`self.extra_env <meta_package_manager.base.PackageManager.extra_env>`
+        * ``auto_extra_env=False`` to skip the automatic addition of
+          :py:attr:`self.extra_env <meta_package_manager.base.PackageManager.extra_env>`
         * ``override_extra_env=dict()`` to locally overrides the later
-        * ``force_exec`` ignores the :option:`mpm --dry-run` and :option:`mpm --stop-on-error` options to force
-          the execution and completion of the command.
+        * ``force_exec`` ignores the :option:`mpm --dry-run` and :option:`mpm
+          --stop-on-error` options to force the execution and completion of the command.
         """
         cli = self.build_cli(
             *args,
@@ -742,16 +848,20 @@ class PackageManager(metaclass=MetaPackageManager):
     def query_parts(cls, query: str) -> set[str]:
         """Returns a set of all contiguous alphanumeric string segments.
 
-        Contrary to :py:class:`meta_package_manager.version.TokenizedString`, do no splits on colated number/alphabetic junctions.
+        Contrary to :py:class:`meta_package_manager.version.TokenizedString`, do no
+        splits on colated number/alphabetic junctions.
         """
         return {p for p in re.split(r"\W+", query) if p}
 
     def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Search packages available for install.
 
-        There is no need for this method to be perfect and sensitive to ``extended`` and ``exact`` parameters. If the package manager
-        is not supporting these kind of options out of the box, just returns the closest subset of matching package you can
-        come up with. Finer refiltering will happens in the :py:meth:`meta_package_manager.base.PackageManager.refiltered_search` method below.
+        There is no need for this method to be perfect and sensitive to ``extended`` and
+        ``exact`` parameters. If the package manager is not supporting these kind of
+        options out of the box, just returns the closest subset of matching package you
+        can come up with. Finer refiltering will happens in the
+        :py:meth:`meta_package_manager.base.PackageManager.refiltered_search` method
+        below.
 
         Optional. Will be simply skipped by :program:`mpm` if not implemented.
         """
@@ -837,11 +947,13 @@ class PackageManager(metaclass=MetaPackageManager):
 
         If the manager doesn't provides a full upgrade one-liner (i.e. if
         :py:meth:`meta_package_manager.base.PackageManager.upgrade_all_cli` raises
-        :py:exc:`NotImplementedError`), then the list of all outdated packages will be fetched
-        (via :py:meth:`meta_package_manager.base.PackageManager.outdated`) and each package will be
-        updated one by one by calling :py:meth:`meta_package_manager.base.PackageManager.upgrade_one_cli`.
+        :py:exc:`NotImplementedError`), then the list of all outdated packages will be
+        fetched (via :py:meth:`meta_package_manager.base.PackageManager.outdated`) and
+        each package will be updated one by one by calling
+        :py:meth:`meta_package_manager.base.PackageManager.upgrade_one_cli`.
 
-        See for example the case of :py:meth:`meta_package_manager.managers.pip.Pip.upgrade_one_cli`.
+        See for example the case of
+        :py:meth:`meta_package_manager.managers.pip.Pip.upgrade_one_cli`.
         """
         if package_id:
             cli = self.upgrade_one_cli(package_id, version=version)
@@ -851,7 +963,7 @@ class PackageManager(metaclass=MetaPackageManager):
                 cli = self.upgrade_all_cli()
             except NotImplementedError:
                 logger.info(
-                    f"Fallback to calling upgrade operation on each outdated package."
+                    "Fallback to calling upgrade operation on each outdated package."
                 )
                 log = ""
                 for package in self.outdated:
