@@ -28,7 +28,8 @@ else:
 from . import logger
 from .base import Package, PackageManager
 
-"""Utilities and helper to organize, inspect and audit the capabilities of mpm and package managers."""
+"""Utilities and helper to organize, inspect and audit the capabilities of mpm and
+package managers."""
 
 P = ParamSpec("P")
 T = TypeVar("T")
