@@ -27,11 +27,11 @@ from ..version import parse_version
 
 
 class Gem(PackageManager):
-
     """
     ..tip::
 
-        Installs require ``sudo`` on system ruby. I (@tresni) recommend doing something like:
+        Installs require ``sudo`` on system ruby. I (@tresni) recommend doing something
+        like:
 
         .. code-block:: shell-session
 
