@@ -26,7 +26,6 @@ from ..capabilities import search_capabilities, version_not_implemented
 
 
 class OPKG(PackageManager):
-
     homepage_url = "https://git.yoctoproject.org/cgit/cgit.cgi/opkg/"
 
     platforms = UNIX_WITHOUT_MACOS
@@ -109,8 +108,10 @@ class OPKG(PackageManager):
             There is no search command so we simulate it by listing all packages.
 
         .. caution::
-            Search does not support extended or exact matching. So we returns the best subset of results and let
-            :py:meth:`meta_package_manager.base.PackageManager.refiltered_search` refine them.
+            Search does not support extended or exact matching. So we returns the best
+            subset of results and let
+            :py:meth:`meta_package_manager.base.PackageManager.refiltered_search` refine
+            them.
 
         .. code-block:: shell-session
 
