@@ -26,7 +26,6 @@ from ..capabilities import search_capabilities, version_not_implemented
 
 
 class Snap(PackageManager):
-
     homepage_url = "https://snapcraft.io"
 
     platforms = UNIX_WITHOUT_MACOS
@@ -95,8 +94,9 @@ class Snap(PackageManager):
         """Fetch matching packages.
 
         .. caution::
-            Search is extended by default. So we returns the best subset of results and let
-            :py:meth:`meta_package_manager.base.PackageManager.refiltered_search` refine them.
+            Search is extended by default. So we returns the best subset of results and
+            let :py:meth:`meta_package_manager.base.PackageManager.refiltered_search`
+            refine them.
 
         .. code-block:: shell-session
 
